@@ -10,7 +10,7 @@ BEGIN {
   $_scode = inet_aton('127.0.0.0');
 }
 
-$VERSION = do { my @r = (q$Revision: 0.35 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 0.36 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 use AutoLoader 'AUTOLOAD';
 
@@ -212,8 +212,11 @@ Mail::SpamCannibal::ScriptSupport - A collection of script helpers
 
   $object = new Mail::Spamcannibal::ScriptSupport;
   $rv = $object->dns2rblz($line);
+  $firstline = $object->rbldns_combined($type);
   $textline = $object->rbldns_compress($textline);
+  $lastline = $object->rbldnst_done();
   $lastline = $object->rbldns_done();
+  $last_combined = rbldns_address();
 
 =head1 DESCRIPTION
 
@@ -1686,20 +1689,25 @@ sub dns2rblz {
 	$self->{soa} .= $& || '';
 	$self->{soa} =~ s/[\r\n\(]+/ /g;# convert CRLF's and '(' to space
 	$self->{soa} =~ s/\s+/ /g;	# multiple spaces to single space
-	$out = "\n#". $self->{soa};
+	while ($self->{soa} =~ / $/) { chop $self->{soa} };
+	$self->{soa} =~ /\d+$/;		# extract ttl
+	$self->{ttl} = $&;
+	$self->{soa} =~ s/SOA/SOA $self->{ttl}/i;
+	$out = "\n#\$". $self->{soa};
 	$self->{soa} = '';		# clear flag
       }
     } 
     elsif ($in =~ /^\$ORIGIN\s+(.+)/) {
       $self->{origin} = $1;
-      $self->{origin} =~ s/\.$self->{base}//i
+      $self->{origin} =~ s/[\.]?$self->{base}//i	# strip base (w/wout leading dot if origin is 'base')
 	if $self->{base};
     }
     elsif ($in =~ /^(\$TTL\s+(\d+))/) {
       $out = "\n#$1" if $2 > 0;
+      $self->{ttl} = $2;
     }
-    elsif ($in =~ /^([0-9.]+).+A\s+([0-9.]+)/) {	# A record
-      my $rip = $1 .'.'.$self->{origin};
+    elsif ($in =~ /^([0-9.]+).+A\s+([0-9.]+)/) {	# numeric A record
+      my $rip = $1 .'.'. $self->{origin};
       @_ = reverse split(/\./,$rip);
       $self->{IP} = join('.',@_);
       $out = "\n". $self->{IP};				# print the record
@@ -1725,6 +1733,18 @@ sub dns2rblz {
       $self->{soa} = $2;			# save soa comments and arm collection of multiple lines
       next if $in =~ /\)/;			# closing bracket
     }
+    elsif ($in =~ /^\s.+NS\s+(.+)/) {	# NS record
+      if ($self->{ns}) {
+	$self->{ns} .= ' '. $1;
+      } else {
+	$self->{ns} = "#\$NS ". ($self->{ttl} || 0) .' '. $1;
+      }
+    }
+    elsif ($in =~ /^\s.+A\s+(.+)/) {	# NS A record
+      $self->{nsa} = $self->{nsa}
+	? "\n" : '';
+	$self->{nsa} .= '@ '. ($self->{ttl} || 0) .' A '. $1;
+    }
 # ignore anything else
     last;
   }
@@ -1782,6 +1802,44 @@ sub rbldns_compress {
   return $line;
 }
 
+=item * $firstline = $object->rbldns_combined($type);
+
+Write the first line of an B<rbldns> combined dataset of type 
+B<ip4set | ip4tset>.
+
+  input:	type, one of ip4set or ip4tset
+  returns:	dataset statement for ip4set
+	    or	undef on error
+
+=cut
+
+sub rbldns_combined {
+  my($self,$type) = @_;
+  return undef unless $type eq 'ip4set' or $type eq 'ip4tset';
+  return '$DATASET '. $type .' @
+';
+}
+
+=item * $last_combined = rbldns_address();
+
+Write the generic format address record(s) for the name server
+within this address. This should be the last record after the ip4set is
+generated using a starting header generated by B<rbldns_combined> (above).
+
+  input:	none
+  returns:	dataset statement + address
+
+=cut
+
+sub rbldns_address {
+  my $self = shift;
+  if ($self->{nsa}) {
+    return'$DATASET generic @
+'. $self->{nsa} ."\n";
+  }
+  return '';
+}
+
 =item * $lastline = $object->rbldns_done();
 
 Complete the last line of an ip4set dataset conversion.
@@ -1792,16 +1850,38 @@ Complete the last line of an ip4set dataset conversion.
 
 =cut
 
-sub rbldns_done {
-  my $rbl = shift;
-  if ($rbl->{first} == $rbl->{last}) {
-    return "\n";
-  } else {
-    return '-'. $rbl->{last} ."\n";
+sub _add_nsrecord {
+  my($self,$line) = @_;
+  if ($self->{ns}) {
+    $line .= $self->{ns} ."\n";
   }
+  return $line;
 }
 
+sub rbldns_done {
+  my $rbl = shift;
+  my $rv;
+  if ($rbl->{first} == $rbl->{last}) {
+    $rv = "\n";
+  } else {
+    $rv = '-'. $rbl->{last} ."\n";
+  }
+  return _add_nsrecord($rbl,$rv);
+}
 
+=item * $lastline = $object->rbldnst_done();
+
+Complete the last line of an ip4tset dataset conversion.
+
+  input:	none
+  returns:	remainder of last line
+		in the ip4tset data file
+
+=cut
+
+sub rbldnst_done {
+  return _add_nsrecord($_[0],"\n");
+}
 
 =pod
 
